diff --git a/htdocs/core/class/html.formticket.class.php b/htdocs/core/class/html.formticket.class.php
index a34861e17d6..a397433979b 100644
--- a/htdocs/core/class/html.formticket.class.php
+++ b/htdocs/core/class/html.formticket.class.php
@@ -1,7 +1,7 @@
* Copyright (C) 2016 Christophe Battarel
- * Copyright (C) 2019 Frédéric France
+ * Copyright (C) 2019-2022 Frédéric France
* Copyright (C) 2021 Juanjo Menent
* Copyright (C) 2021 Alexandre Spangaro
*
@@ -50,9 +50,15 @@ class FormTicket
/**
* @var string The track_id of the ticket. Used also for the $keytoavoidconflict to name session vars to upload files.
+ * @deprecated
*/
public $track_id;
+ /**
+ * @var string trackid
+ */
+ public $trackid;
+
/**
* @var int ID
*/
@@ -89,8 +95,12 @@ class FormTicket
public $withusercreate; // to show name of creating user in form
public $withcreatereadonly;
- public $withref; // to show ref field
+ /**
+ * @var int withextrafields
+ */
+ public $withextrafields;
+ public $withref; // to show ref field
public $withcancel;
public $type_code;